@@ -444,23 +444,40 @@ impl<'a> Scope {
         self.functions.lock().unwrap().insert(name, func);
     }
     /// Get a function by name.
-    pub fn get_function(&self, name: &Name) -> Option<Function> {
+    pub fn get_function(
+        &self,
+        name: &Name,
+    ) -> Result<Option<Function>, Error> {
         if let Some((modulename, name)) = name.split_module() {
-            self.get_module(&modulename)
-                .and_then(|m| m.get_function(&name))
+            if let Some(module) = self.get_module(&modulename) {
+                if let Some(f) = module.get_function(&name)? {
+                    Ok(Some(f))
+                } else {
+                    Err(Error::error("Undefined function"))
+                }
+            } else {
+                return Err(Error::error(format!(
+                    "There is no module with the namespace {:?}",
+                    modulename
+                )));
+            }
         } else {
             let f = self.functions.lock().unwrap().get(name).cloned();
             if let Some(f) = f {
-                Some(f)
+                Ok(Some(f))
             } else if let Some(ref parent) = self.parent {
                 parent.get_function(name)
-            } else if self.get_name() == "" {
-                Function::get_builtin(name).cloned()
             } else {
-                None
+                Ok(None)
             }
         }
     }
+
+    /// Only for exposing builtin functions; will panic on unknown.
+    pub(crate) fn get_lfunction(&self, name: &Name) -> Function {
+        self.functions.lock().unwrap().get(name).unwrap().clone()
+    }
+
     /// Get the selectors active for this scope.
     pub fn get_selectors(&self) -> &Selectors {
         lazy_static! {
@@ -511,7 +528,7 @@ impl<'a> Scope {
                 }
                 for (name, m) in &*module.mixins.lock().unwrap() {
                     let name = format!("{}{}", prefix, name).into();
-                    if dbg!(expose.allow_fun(dbg!(&name))) {
+                    if expose.allow_fun(&name) {
                         self.define_mixin(name, m.clone());
                     }
                 }
@@ -520,7 +537,7 @@ impl<'a> Scope {
         Ok(())
     }
 
-    fn expose_star(&self, other: &Scope) {
+    pub(crate) fn expose_star(&self, other: &Scope) {
         for (name, function) in &*other.functions.lock().unwrap() {
             self.define_function(name.clone(), function.clone());
         }
@@ -890,7 +907,10 @@ pub mod test {
         s: &[(&'static str, &str)],
         expression: &[u8],
     ) -> String {
-        do_evaluate_or_error(s, expression).unwrap()
+        match do_evaluate_or_error(s, expression) {
+            Ok(v) => v,
+            Err(e) => panic!("{}", e),
+        }
     }
 
     pub fn do_evaluate_or_error(
